package com.teamchat.client.sdk.demo;

import com.teamchat.client.annotations.OnAlias;
import com.teamchat.client.annotations.OnKeyword;
import com.teamchat.client.sdk.Form;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.PrimaryChatlet;
import com.teamchat.client.sdk.impl.TeamchatAPIImpl;

/**
 * The bot posts multi-field form using primary chatlet when user sends "create"
 * keyword. It contains different types of fields, text and dropdown
 * 
 * It shows how to enabled comments, details and set labels for replies
 * 
 * It also demonstrate how to set alias on the form and handle replies made by
 * users
 * 
 * Please remember to update the authKey
 */
public class PostPrimaryChatletDemo {
	public static final String authKey = "samplekey";

	public static void main(String[] args) {
		TeamchatAPI api = TeamchatAPIImpl.fromFile("config.json").setAuthenticationKey(authKey);

		api.startReceivingEvents(new PostPrimaryChatletDemo());
	}

	/*
	 * This method will be called when user sends a keyword "create" in the room
	 */
	@OnKeyword("create")
	public void onCreate(TeamchatAPI api) {
		PrimaryChatlet p = new PrimaryChatlet();

		// Set the question for the chatlet
		p.setQuestion("Please enter your profile");

		// alternatively HTML can also be set for question
		// p.setQuestionHtml("<b><font style=\"color:red\">Please enter your profile</font></b>");

		// Create reply form for this primary chatlet and add fields to it
		Form f = api.objects().form();

		// a text field to enter name
		f.addField(api.objects().input().name("name").label("Name:"));

		// a dropdown to select city
		f.addField(api.objects().select().name("city").label("City")
				.addOption("Delhi").addOption("Mumbai").addOption("Kolkata")
				.addOption("Chennai"));
		// a contact field
		f.addField(api.objects().attachContacts(true).name("mycontact")
				.label("myContact"));
		// a location field
		f.addField(api.objects().attachLocation().name("loc")
				.label("myLocation"));
		// a file field with size in bytes
		f.addField(api.objects().attachFile("10000000", "*").name("myfile")
				.label("myfile"));
		// a image field with size in bytes
		f.addField(api.objects().attachImage("1000000000").name("myimage")
				.label("myimage"));
		// a radio button
		f.addField(api.objects().radio("value1").name("myRadio")
				.label("myRadio").addOption("value2").addOption("value3")
				.addOption("value4"));
		
		// a check box button
		f.addField(api.objects().checkbox("value1").name("mycheckbox")
						.label("mycheckbox").addOption("value2").addOption("value3")
						.addOption("value4"));
		// finally add this Form to primary chatlet as replyscreen
		p.setReplyScreen(f);

		// Decide if replies will be visible to everyone in the room
		// Also, label can be changed
		p.showDetails(true);
		p.setDetailsLabel("Entries");

		// Decide if commenting is enabled on this chatlet or not
		p.allowComments(true);

		// Can change reply button label
		p.setReplyLabel("Enter");

		// Can assign an alias, if you want to handle replies on this chatlet
		// The method with @OnAlias annotation will be called, when anyone
		// replies
		// to this chatlet. For example, look at method handleReply in this
		// class
		// it has annotation @OnAlias("profile"), which we are setting below.
		p.alias("profile");

		// finally post the chatlet in the current room
		api.performPostInCurrentRoom(p);
	}

	/*
	 * This method prints the replies to the chatlet that was posted in the
	 * create method.
	 */
	@OnAlias("profile")
	public void handleReply(TeamchatAPI api) {
		// email of the user who replied
		System.out.println("Sender:"
				+ api.context().currentReply().senderEmail());

		// value entered in the field "name" and "city"
		System.out.println("Name entered:"
				+ api.context().currentReply().getField("name"));
		System.out.println("City entered:"
				+ api.context().currentReply().getField("city"));
		System.out.println("mycontact entered:"
				+ api.context().currentReply().getContactDetails("mycontact"));
		System.out.println("myfile entered:"
				+ api.context().currentReply().getFileUploadDetails("myfile")
						.getFileName());
		System.out.println("myimage entered:"
				+ api.context().currentReply().getFileUploadDetails("myimage")
						.getFileName());
		System.out.println("loc entered:"
				+ api.context().currentReply().getLocationInfo("loc")
						.getLocName());
		System.out.println("myradio entered :"+ api.context().currentReply().getField("myRadio"));
		
		System.out.println("mycheckbox entered :"+ api.context().currentReply().getField("mycheckbox"));
	}
}
